package net.pricefx.common.apibuilder.chart;

import java.util.ArrayList;
import java.util.List;

import net.pricefx.common.api.chart.AuxLineColor;
import net.pricefx.common.api.chart.ColorAxisType;
import net.pricefx.common.api.chart.ComparisonType;
import net.pricefx.common.api.chart.FilterOperator;
import net.pricefx.common.api.chart.LimitPosition;
import net.pricefx.common.api.chart.LimitType;
import net.pricefx.common.api.chart.SeriesType;
import net.pricefx.common.api.chart.SortType;
import net.pricefx.common.api.chart.WaterfallColumnType;
import net.pricefx.common.api.chart.WhiskerType;
import net.pricefx.common.apibuilder.BuilderExtensions.GroovyDefaultImport;
import net.pricefx.common.apibuilder.chart.AuxLine.Line;
import net.pricefx.common.apibuilder.chart.AuxLine.SteppedLine;
import net.pricefx.common.apibuilder.chart.AuxLine.VerticalLine;
import net.pricefx.common.apibuilder.chart.BarLineChart.BarLineAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.BarLineChart.BarLineOptions;
import net.pricefx.common.apibuilder.chart.BarLineChart.BarLineSeries;
import net.pricefx.common.apibuilder.chart.BoxplotChart.BoxplotAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.BoxplotChart.BoxplotOptions;
import net.pricefx.common.apibuilder.chart.BoxplotChart.BoxplotSeries;
import net.pricefx.common.apibuilder.chart.BubbleChart.BubbleAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.BubbleChart.BubbleOptions;
import net.pricefx.common.apibuilder.chart.BubbleChart.BubbleSeries;
import net.pricefx.common.apibuilder.chart.BubbleChart.BubbleSize;
import net.pricefx.common.apibuilder.chart.DataTableChart.DataTableAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.DataTableChart.DataTableOptions;
import net.pricefx.common.apibuilder.chart.DataTableChart.DataTableSeries;
import net.pricefx.common.apibuilder.chart.DetailedTimeSeriesChart.DetailedTimeSeriesAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.DetailedTimeSeriesChart.DetailedTimeSeriesOptions;
import net.pricefx.common.apibuilder.chart.DetailedTimeSeriesChart.DetailedTimeSeriesSeries;
import net.pricefx.common.apibuilder.chart.HeatmapChart.HeatmapAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.HeatmapChart.HeatmapInterpolatedColorAxis;
import net.pricefx.common.apibuilder.chart.HeatmapChart.HeatmapOptions;
import net.pricefx.common.apibuilder.chart.HeatmapChart.HeatmapRangedColorAxis;
import net.pricefx.common.apibuilder.chart.HeatmapChart.HeatmapSeries;
import net.pricefx.common.apibuilder.chart.HistogramChart.HistogramAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.HistogramChart.HistogramOptions;
import net.pricefx.common.apibuilder.chart.HistogramChart.HistogramSeries;
import net.pricefx.common.apibuilder.chart.PieChart.PieAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.PieChart.PieOptions;
import net.pricefx.common.apibuilder.chart.PieChart.PieSeries;
import net.pricefx.common.apibuilder.chart.PieChart.Size;
import net.pricefx.common.apibuilder.chart.ScatterChart.ScatterAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.ScatterChart.ScatterOptions;
import net.pricefx.common.apibuilder.chart.ScatterChart.ScatterSeries;
import net.pricefx.common.apibuilder.chart.TimeSeriesChart.TimeSeriesAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.TimeSeriesChart.TimeSeriesOptions;
import net.pricefx.common.apibuilder.chart.TimeSeriesChart.TimeSeriesSeries;
import net.pricefx.common.apibuilder.chart.TimeSeriesScatterChart.TimeSeriesScatterAdditionalMeasure;
import net.pricefx.common.apibuilder.chart.TimeSeriesScatterChart.TimeSeriesScatterOptions;
import net.pricefx.common.apibuilder.chart.TimeSeriesScatterChart.TimeSeriesScatterSeries;
import net.pricefx.common.apibuilder.chart.WaterfallChart.WaterfallOptions;
import net.pricefx.common.apibuilder.chart.WaterfallChart.WaterfallSeries;
import net.pricefx.common.apibuilder.chart.WaterfallComparisonChart.WaterfallComparisonOptions;
import net.pricefx.common.apibuilder.chart.WaterfallComparisonChart.WaterfallComparisonSeries;

public class ChartBuilderExtensions {

	public static boolean isBuilderClass(Object o) {
		return 
		o instanceof ChartBuilder ||
		
		o instanceof AggrFieldAxis ||
		o instanceof NonAggrFieldAxis ||
		o instanceof Formula||
		o instanceof Expression ||

		o instanceof LimitToMeasure ||
		o instanceof LimitPosition ||
		o instanceof LimitType ||
		
		o instanceof Filters ||
		o instanceof FilterOperator ||
		
		o instanceof Dictionary ||

		o instanceof AuxLine ||
		o instanceof AuxLineColor ||
		o instanceof Line ||
		o instanceof SteppedLine ||
		o instanceof VerticalLine ||
		o instanceof TrendLine ||

		o instanceof ScatterChart ||
		o instanceof ScatterSeries ||
		o instanceof ScatterOptions ||
		o instanceof ScatterAdditionalMeasure ||
		
		o instanceof TimeSeriesScatterChart ||
		o instanceof TimeSeriesScatterSeries ||
		o instanceof TimeSeriesScatterOptions ||
		o instanceof TimeSeriesScatterAdditionalMeasure ||
		
		o instanceof BarLineChart ||
		o instanceof BarLineSeries ||
		o instanceof BarLineOptions ||
		o instanceof ComparisonType ||
		o instanceof BarLineAdditionalMeasure ||
		o instanceof SeriesType ||
		o instanceof SortType ||
		
		o instanceof BubbleChart ||
		o instanceof BubbleSeries ||
		o instanceof BubbleOptions ||
		o instanceof BubbleAdditionalMeasure ||
		o instanceof BubbleSize ||
		
		o instanceof PieChart ||
		o instanceof PieSeries ||
		o instanceof PieOptions ||
		o instanceof Size ||
		o instanceof PieAdditionalMeasure||
		
		o instanceof WaterfallChart ||
		o instanceof WaterfallSeries ||
		o instanceof WaterfallOptions ||
		o instanceof WaterfallColumnType ||
		
		o instanceof WaterfallComparisonChart ||
		o instanceof WaterfallComparisonSeries ||
		o instanceof WaterfallComparisonOptions ||
		
		o instanceof TimeSeriesChart ||
		o instanceof TimeSeriesSeries ||
		o instanceof TimeSeriesOptions ||
		o instanceof TimeSeriesAdditionalMeasure ||

		o instanceof DetailedTimeSeriesChart ||
		o instanceof DetailedTimeSeriesSeries ||
		o instanceof DetailedTimeSeriesOptions ||
		o instanceof DetailedTimeSeriesAdditionalMeasure ||
		
		o instanceof HistogramChart ||
		o instanceof HistogramSeries ||
		o instanceof HistogramOptions ||
		o instanceof HistogramAdditionalMeasure ||
		
		o instanceof BoxplotChart ||
		o instanceof BoxplotSeries ||
		o instanceof BoxplotOptions ||
		o instanceof BoxplotAdditionalMeasure ||
		o instanceof WhiskerType ||
		
		o instanceof DataTableChart ||
		o instanceof DataTableSeries ||
		o instanceof DataTableOptions ||
		o instanceof DataTableAdditionalMeasure ||
		
		o instanceof HeatmapChart ||
		o instanceof HeatmapSeries ||
		o instanceof HeatmapOptions ||
		o instanceof HeatmapRangedColorAxis ||
		o instanceof HeatmapInterpolatedColorAxis ||
		o instanceof HeatmapAdditionalMeasure ||
		o instanceof ColorAxisType;
	}
	
	public static List<GroovyDefaultImport> getGroovyDefaultImports() {
		ArrayList<GroovyDefaultImport> defaultImports = new ArrayList<GroovyDefaultImport>();

		defaultImports.add(new GroovyDefaultImport("AuxLineColor", AuxLineColor.class));
		defaultImports.add(new GroovyDefaultImport("FilterOperator", FilterOperator.class));
		defaultImports.add(new GroovyDefaultImport("SeriesType", SeriesType.class));
		defaultImports.add(new GroovyDefaultImport("SortType", SortType.class));
		defaultImports.add(new GroovyDefaultImport("WhiskerType", WhiskerType.class));
		defaultImports.add(new GroovyDefaultImport("WaterfallColumnType", WaterfallColumnType.class));
		defaultImports.add(new GroovyDefaultImport("LimitPosition", LimitPosition.class));
		defaultImports.add(new GroovyDefaultImport("LimitType", LimitType.class));
		defaultImports.add(new GroovyDefaultImport("ColorAxisType", ColorAxisType.class));
		defaultImports.add(new GroovyDefaultImport("ComparisonType", ComparisonType.class));
		
		return defaultImports;
	}
	
	// class.isInstance not supported by gwt compiler
	public static boolean isDefaultImport(Object o) {
		if (o instanceof AuxLineColor ||
			o instanceof FilterOperator ||
			o instanceof SeriesType ||
			o instanceof SortType ||
			o instanceof WhiskerType ||
			o instanceof ComparisonType ||
			o instanceof WaterfallColumnType ||
			o instanceof LimitPosition ||
			o instanceof LimitType ||
			o instanceof ColorAxisType) return true;
		
		return false;
	}
	
	public static boolean isClass(Object o) {
		if (o == AuxLineColor.class ||
			o == FilterOperator.class ||
			o == SeriesType.class ||
			o == SortType.class ||
			o == WhiskerType.class ||
			o == ComparisonType.class ||
			o == WaterfallColumnType.class ||
			o == LimitPosition.class ||
			o == LimitType.class ||
			o == ColorAxisType.class) return true;
			
		return false;
	}
	
}
