package net.pricefx.common.apibuilder.contract;

import java.util.Map;

import net.pricefx.common.api.HeaderPhase;
import net.pricefx.common.apibuilder.IdGenerator;
import net.pricefx.common.apibuilder.Invocations;
import net.pricefx.common.apibuilder.MethodInvocation;
import net.pricefx.common.apibuilder.clicoll.CalculableLineItemCollectionBuilder;

/**
 * Please read notes in {@link CalculableLineItemCollectionBuilder} on how to use this builder.
 * @see CalculableLineItemCollectionBuilder
 *
 */
public class ContractBuilder extends CalculableLineItemCollectionBuilder<ContractBuilder> {

	// read only state, don't get propagated further, it is here for user convenience
	private final Object contractView;
	private final ContractHelper helper;
	
	@SuppressWarnings("unchecked")
	ContractBuilder(String instanceId, String classId, IdGenerator idGenerator, Invocations<MethodInvocation> invocations, Object contractView, HeaderPhase phase) {
		super(instanceId, classId, idGenerator, invocations, phase);
		this.contractView = contractView;
		this.helper = new ContractHelper((Map<String, Object>) contractView);
	}

	
	public Object getContractView() {
		addInvocation("getContractView");
		return contractView;
	}
	
	public ContractHelper getHelper() {
		addInvocation("getHelper");		
		return helper;
	}	
	
	@Override
	public ContractBuilderResult build() {
		addInvocation(METHOD_BUILD);

		ContractBuilderResult r = new ContractBuilderResult();
		r.invocations = invocations.get();
		return r;
	}

	public ContractBuilder addContractStructure(Object structure) {
		addInvocation("addContractStructure", structure);
		return this;
	}

	/**
	 * Creates and adds a new folder under the ROOT folder. 
	 * <p>
	 * If you intend to add many folders and items, use the ContractStructure approach instead.
	 */
	public void addFolder(String label) {
	}

}