package net.pricefx.logic.core.model;

import java.awt.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ElementPoint extends Point {
    private String elementName;
    private String errorMessage;
    private String errorMessageHtml;
    private String vieElementName;

    ElementPoint(String elementName, String vieElementName, String errorMessage, int x, int y) {
        super(x, y);
        this.elementName = elementName;
        this.vieElementName = vieElementName;
        this.errorMessage = errorMessage;
        this.errorMessageHtml = errorMessage == null ? null : errorMessage.replaceAll("\\n", "<br>");
    }

    public static ElementPoint parseElementResult(String result) {
        if (result == null) {
            return null;
        }
        ElementPoint elementPoint = null;

        String pattern = "(\\w+)(?: \\[via (.+)\\])? : (?:ERROR\\(@(\\d+)\\): )?(.*)";
        Pattern r = Pattern.compile(pattern);

        Matcher matcher = r.matcher(result);
        if (matcher.find() && matcher.groupCount() == 4) {
            try {
                String lineNumber = matcher.group(3);
                String elementName = matcher.group(1);
                String vieElementName = matcher.group(2);
                String errorMessage = matcher.group(4);
                int x = lineNumber == null ? 0 : Integer.parseInt(lineNumber) - 1;
                int y = 0;

                pattern = ": \\d+: (.+ @ line (\\d+), column (\\d+)\\.[\\S\\s]*)";
                r = Pattern.compile(pattern);

                matcher = r.matcher(result);

                if (matcher.find() && matcher.groupCount() == 3) {
                    errorMessage = matcher.group(1);
                    x = Integer.parseInt(matcher.group(2)) - 1;
                    y = Integer.parseInt(matcher.group(3)) - 1;
                }

                elementPoint = new ElementPoint(elementName, vieElementName, errorMessage, x, y);
            } catch (NumberFormatException e) {
                return null;
            }
        }

        return elementPoint;
    }

    public String getElementName() {
        return elementName;
    }

    public String getVieElementName() {
        return vieElementName;
    }

    public String getErrorMessage() {
        return errorMessage;
    }
    public String getErrorMessageHtml() {
        return errorMessageHtml;
    }
}
